<!-- -*- mode: markdown; mode: flyspell -*- -->
# GitLab Bot Tools
Collection of bot tools for GitLab.


## Table of Contents
[[_TOC_]]


## Bot Tools
### gitlab-issue-assigner
```
usage: gitlab-issue-assigner [options] <project>

  This script assigns all unassigned issues from one or more given
  projects to a given user.

  options:
  -h         .. show this help message
  -d         .. run in debug mode (like -vvv but only to log)
  -n         .. dry run, only check for unassigned issues
  -q         .. run quietly
  -v         .. increase verbosity (max 3)
  -u <user>  .. assign issues to <user> (may be a username or id)

  Note: -u is mandatory!

  User and projects may be names (project names must be with namespace!)
  or IDs.
```

#### Examples
```
gitlab-issue-assigner -u LabsTeam zkklabs/dslab zkklabs/inflab zkklabs/tilab
gitlab-issue-assigner -u 44 zkklabs/dslab 18 zkklabs/tilab
```


### gitlab-add-members
```
usage: gitlab-add-members [options]

  This script adds all existing users from a given file to a given
  project or group.

  options:
  -a <int>   .. access-level for added users, see
                https://docs.gitlab.com/ee/api/access_requests.html
  -h         .. show this help message
  -i <file>  .. input file has one key per line
  -k <key>   .. key for input file
  -l <file>  .. logfile to use, default:
                $HOME/log/${0##*/}.log
  -L         .. do not use a logfile
  -m <mode>  .. mode must be one of: project, group
  -p <path>  .. project/target-path is the path with namespace
```


### gitlab-copy-issue-to-comment
```
usage: gitlab-copy-issue-to-comment [options] <project>

  This script copies a given issue as a comment to an other given issue
  in the same project.

  options:
  -b <string>  .. target issue label
  -c <string>  .. use this as comment title
  -C           .. do not use a comment title
  -d           .. run in debug mode (like -vvv but only to log)
  -h           .. show this help message
  -i <int>     .. source issue project internal id (iid)
  -l <file>    .. logfile to use, default:
                  $HOME/log/${0##*/}.log
  -L           .. do not use a logfile
  -n           .. dry run, only check for unassigned issues
  -p <project> .. project to work in (namespace with path or id)
  -q           .. run quietly
  -r           .. preserve reactions
  -R           .. do not preserve comments and reactions
  -s           .. preserve issue create date
  -S           .. preserve comment create date
  -t <issue>   .. target issue (title or iid)
  -u           .. preserve issue creator (requires token with sudo scope)
  -U           .. preserve comment creator (requires token with sudo scope)
  -v           .. increase verbosity (max 3)

  Note: -i, -p and -t are mandatory!

  Note: currently -R is mandatory due to not implemented
        comment/reactions preservation!

  Project may be a project name with namespace or an ID. Target issue
  may be a title or an IID. If it is a title, the newest issue to match
  the title will be used.
```


## Dependencies
### bash-base
`bash-base` is a base library for bash.

Execute the following code to install `bash-base`:
```
yum makecache && yum install -y bash-base
```

The documentation for `bash-base` may be found here:
https://git.labs.zkk.tuwien.ac.at/sw/bash-base

### jq
`jq` is used to parse the json answers from GitLab.

Execute the following code to install `jq`:
```
yum makecache && yum install -y jq
```

For the documentation of `jq` just type `man jq` in your terminal.


### python-gitlab
`python-gitlab` is used to communicate to GitLab.

Execute the following code to install `python-gitlab`:
```
# as root
yum makecache && yum install -y python3-pip
# as bot-user
pip3 install --user --upgrade python-gitlab
```

The documentation for `python-gitlab` may be found here:
https://python-gitlab.readthedocs.io


### All Together
If you want to install all dependencies in one run, execute the
following code:
```
# as root
yum makecache && yum install -y bash-base jq python3-pip
# as bot-user
pip3 install --user --upgrade python-gitlab
```


## Meta
### Logo
`botvatar` is the default [GitLab](https://gitlab.com)
[tanuki](https://en.wikipedia.org/wiki/Japanese_raccoon_dog) made blue
to look more metallic with a sliding single red eye to making it look
like a
[Cylon](https://en.wikipedia.org/wiki/Cylon_(Battlestar_Galactica)). The
logo is subject to the terms of the [CC BY-NC-SA
4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/).


<!--
LocalWords: Cylon GitLab TOC gitlab logfile namespace tunaki
 -->
